@@ -195,13 +195,14 @@ sub render_data {
 }
 
 sub render_complete {
+    require Swim;
     my ($self, $out) = @_;
     chomp $out;
     <<"..."
 =pod
 
 =for comment
-DO NOT EDIT. This Pod was generated by Swim.
+DO NOT EDIT. This Pod was generated by Swim v$Swim::VERSION.
 See http://github.com/ingydotnet/swim-pm#readme
 
 =encoding utf8
